﻿using Infragistics.Win.DataVisualization;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace DataGridVerticalGridlines
{
    public partial class Form1 : Form
    {
        int scale = 50;
        List<DataChartLine> lines = new List<DataChartLine>();

        public Form1()
        {
            InitializeComponent();

            Width = 800;
            Height = 800;

            #region Chart Setup

            TestData testData = new TestData(scale);
            CategoryXAxis categoryX = new CategoryXAxis();
            categoryX.DataSource = testData;

            NumericYAxis numericY = new NumericYAxis();
            numericY.MaximumValue = scale;
            numericY.MinimumValue = -scale;

            categoryX.Title = "Time";
            numericY.Title = "Count";

            ultraChart.Axes.Add(categoryX);
            ultraChart.Axes.Add(numericY);

            LineSeries lineSeries = new LineSeries();
            lineSeries.Title = "Contacts Added";
            lineSeries.XAxis = categoryX;
            lineSeries.YAxis = numericY;
            lineSeries.DataSource = testData;
            lineSeries.Thickness = 1.5;
            lineSeries.Brush = new Infragistics.Win.DataVisualization.SolidColorBrush(Color.LimeGreen);

            LineSeries lineSeries2 = new LineSeries();
            lineSeries2.Title = "Contacts Deleted";
            lineSeries2.XAxis = categoryX;
            lineSeries2.YAxis = numericY;
            lineSeries2.DataSource = new TestData(-scale);
            lineSeries2.Thickness = 1.5;
            lineSeries2.Brush = new Infragistics.Win.DataVisualization.SolidColorBrush(Color.Red);

            ultraChart.Series.Add(lineSeries);
            ultraChart.Series.Add(lineSeries2);

            ultraChart.HorizontalZoomable = true;
            ultraChart.VerticalZoomable = true;

            ultraChart.WindowResponse = WindowResponse.Immediate;
            ultraChart.Dock = DockStyle.Fill;
            Controls.Add(ultraChart);
            ultraChart.Show();

            UltraLegend legend = new UltraLegend();
            legend.Dock = DockStyle.Right;
            ultraChart.Legend = legend;
            Controls.Add(legend);
            legend.Show();

            ultraChart.RefreshCompleted += ultraChart_RefreshCompleted;

#endregion

            DataChartLine mailShot = new DataChartLine(ultraChart, 4.0, "Mailshot", Color.Blue);
            DataChartLine ftAdvert = new DataChartLine(ultraChart, 6.0, "FT Advert", Color.Aqua);
            lines.Add(mailShot);
            lines.Add(ftAdvert);
        }

        void ultraChart_RefreshCompleted(object sender, EventArgs e)
        {
            CategoryXAxis catX = ultraChart.Axes.OfType<CategoryXAxis>().First();
            NumericXAxis numX = ultraChart.Axes.OfType<NumericXAxis>().First();

            foreach (DataChartLine line in lines)
            {
                // Find the X coordinate of our target point
                double pixelValue = catX.ScaleValue(line.TargetValue);

                // If the chart is using a clustering series, we need to offset the line a bit
                bool clusterMode = false;
                if (ultraChart.Series.Where((s) =>
                    s is ColumnSeries ||
                    s is WaterfallSeries ||
                    s is RangeColumnSeries).Any())
                {
                    clusterMode = true;
                }

                if (clusterMode)
                {
                    pixelValue += ultraChart.Series.OfType<CategorySeries>().First()
                        .GetCategoryWidth() / 2.0;
                }

                // Find the value of our target point on the numeric axis
                double axisValue = numX.UnscaleValue(pixelValue);
                line.UpdateLine(axisValue);
            }
        }
    }

    public class TestData : ObservableCollection<double>
    {
        private static Random _rand = new Random();

        public TestData(double scaleFactor)
        {
            for (int i = 0; i < 10; i++)
            {
                Add(_rand.NextDouble() * scaleFactor);
            }
        }
    }
}
